@@ -218,59 +218,6 @@ class Batch(Workflow, ModelSQL, ModelView):
                 'state': 'closed',
                 })
 
-    @classmethod
-    def view_header_get(cls):
-        '''
-        view_header_get was removed in 4.2
-
-        We keep this stub that can be called for custom view headers
-        '''
-        pool = Pool()
-        Batch = pool.get('account.batch')
-        BatchJournal = pool.get('account.batch.journal')
-        Company = pool.get('company.company')
-        Fiscalyear = pool.get('account.fiscalyear')
-        Period = pool.get('account.period')
-        Translation = pool.get('ir.translation')
-
-        context = Transaction().context
-        lang_code = 'en_US'
-        if context.get('company'):
-            company = Company(context['company'])
-            if company.party.lang:
-                lang_code = company.party.lang.code
-
-        def get_translated_item(source, model, lang_code):
-            return (Translation.get_source(model, 'field', lang_code, source)
-                or source)
-
-        batch_string = journal_string = period_string = year_string = ''
-        if context.get('journal'):
-            trans_journal = get_translated_item('Journal',
-                'account.batch.line,journal', lang_code)
-            batch_journal = BatchJournal(context['journal'])
-            journal_string = '%s: %s' % (trans_journal, batch_journal.rec_name)
-        if context.get('batch'):
-            trans_batch = get_translated_item('Batch',
-                'account.batch.line,batch', lang_code)
-            batch = Batch(context['batch'])
-            batch_string = '%s: %s' % (trans_batch, batch.name)
-        if context.get('period'):
-            trans_period = get_translated_item('Period',
-                'account.journal.period,period', lang_code)
-            period = Period(context['period'])
-            period_string = '%s: %s' % (trans_period, period.name)
-        elif context.get('fiscalyear'):
-            trans_fiscalyear = get_translated_item('Fiscal Year',
-                'account.batch.line,fiscalyear', lang_code)
-            fiscalyear = Fiscalyear(context['fiscalyear'])
-            year_string = '%s: %s' % (trans_fiscalyear, fiscalyear.name)
-        return ' | '.join([_f for _f in [
-            batch_string,
-            journal_string,
-            period_string,
-            year_string] if _f])
-
 
 class BatchLine(ModelSQL, ModelView):
     'Account Batch Line'
